==> sovix-0.0.1.5.tar.gz: sovix-0.0.1.5/websrc/Website_ratings.php <==
<?php /* Copyright (C) 2006, 2007 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2006, 2007 David Englund.
This entire article is distributed under the GNU Free Documentation
License, Version 1.2 or any later version.";
if (isset($_GET['sovix__directory__src'])) {
  $sovix__directory__src=$_GET['sovix__directory__src'];
  $sovix__directory__dotsovix=$_GET['sovix__directory__dotsovix'];
 }
else {
  $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
  $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
}
require_once "$sovix__directory__src/header.inc"; ?>

<?php
$sovix__dbconn = pg_connect("host=localhost dbname=public user=fox password=$sovix__postgresql__password")
     or die('Could not connect: ' . pg_last_error());

     $sovix__date = pg_escape_string(stripslashes($_POST['sovix__date']));
     $sovix__time = pg_escape_string(stripslashes($_POST['sovix__time']));
     $sovix__rate = pg_escape_string(stripslashes($_POST['sovix__rate']));
     $sovix__file = pg_escape_string(stripslashes($_POST['sovix__file']));
     $sovix__ip_address = pg_escape_string(stripslashes($_POST['sovix__ip_address']));

     $sovix__query = "INSERT INTO website_ratings (
 date,
 time,
 rate,
 file,
 ip
 )
 VALUES (
 '$sovix__date',
 '$sovix__time',
 '$sovix__rate',
 '$sovix__file',
 '$sovix__ip_address'
 )";
     
     $sovix__array__result = pg_query($sovix__query) or die('Query failed: ' . pg_last_error());
     pg_free_result($sovix__array__result);
pg_close($sovix__dbconn);
?>

<a href="<?php echo $sovix__file ?>">Your vote has been counted. Go back to the website</a>
 

<?php require_once "$sovix__directory__src/footer.inc"; ?>

==> sovix-0.0.1.6.tar.gz: sovix-0.0.1.6/websrc/Website_ratings.php <==
<?php /* Copyright (C) 2006, 2007 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2006, 2007 David Englund.
Permission is granted to copy, distribute and/or modify this document
under the terms of the GNU Free Documentation License, Version 1.2 or any
later version published by the Free Software Foundation; with no Invariant
Sections, with no Front-Cover Texts, and with no Back-Cover Texts.";
if (isset($_GET['sovix__directory__src'])) {
  $sovix__directory__src=$_GET['sovix__directory__src'];
  $sovix__directory__dotsovix=$_GET['sovix__directory__dotsovix'];
 }
else {
  $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
  $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
}
require_once "$sovix__directory__src/header.inc"; ?>

<?php
$sovix__dbconn = pg_connect("host=localhost dbname=public user=fox password=$sovix__postgresql__password")
     or die('Could not connect: ' . pg_last_error());

     $sovix__date = pg_escape_string(stripslashes($_POST['sovix__date']));
     $sovix__time = pg_escape_string(stripslashes($_POST['sovix__time']));
     $sovix__rate = pg_escape_string(stripslashes($_POST['sovix__rate']));
     $sovix__file = pg_escape_string(stripslashes($_POST['sovix__file']));
     $sovix__ip_address = pg_escape_string(stripslashes($_POST['sovix__ip_address']));

     $sovix__query = "INSERT INTO website_ratings (
 date,
 time,
 rate,
 file,
 ip
 )
 VALUES (
 '$sovix__date',
 '$sovix__time',
 '$sovix__rate',
 '$sovix__file',
 '$sovix__ip_address'
 )";
     
     $sovix__array__result = pg_query($sovix__query) or die('Query failed: ' . pg_last_error());
     pg_free_result($sovix__array__result);
pg_close($sovix__dbconn);
?>

<a href="<?php echo $sovix__file ?>">Your vote has been counted. Go back to the website</a>
 

<?php require_once "$sovix__directory__src/footer.inc"; ?>
